
# q-expansion of newform 5780.2.a.q, downloaded from the LMFDB on 09 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 5780
weight = 2
poly_data = [34, 200, -588, -384, 1226, 152, -776, -16, 206, 0, -24, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[10567812, -8406370, -50183456, 18566183, 32286419, -11574938, -7105653, 2960146, 631844, -329634, -19736, 13053], 5841353], [[-5397551, -7957212, 731206, 45171104, -2563205, -30302363, 1445810, 6896805, -271228, -631844, 16362, 19736], 5841353], [[24875675, 6356831, -101997298, -98175463, 113198195, 82213269, -42160734, -24896785, 5961993, 3134166, -271796, -135425], 5841353], [[-11744552, -52410078, 52936266, 129224583, -53599545, -93354948, 19037077, 26952296, -2605786, -3297561, 112715, 140626], 5841353], [[19717433, -17172418, -51042497, 111396373, 23320619, -94227260, -3640828, 28463791, 283535, -3565979, -18945, 155784], 5841353], [[-7548, -296336, 207128, 700436, -281262, -473264, 111029, 132402, -16049, -16054, 724, 684], 22729], [[-44931, 144348, -83127, -469784, 138148, 385230, -57520, -121973, 8502, 16049, -362, -724], 22729], [[-45985, -144348, 105856, 469784, -138148, -385230, 57520, 121973, -8502, -16049, 362, 724], 22729], [[-44070528, -99507487, 133696747, 215666624, -104459311, -139125412, 33102697, 37600762, -4289273, -4443205, 180989, 186258], 5841353], [[6853805, -134990445, 35180080, 357327573, -58431782, -238047587, 22627434, 64266723, -3056274, -7526903, 120812, 313440], 5841353]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1], [0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -1, 0], [1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, -1, 0, -1, 0, 0, 0, 0, 0, -1], [0, 0, 1, 1, 0, -1, 0, -1, -1, 0, 1, 0], [0, 1, 1, 1, 0, -1, -1, -3, -2, 0, 1, 0], [-2, 0, 0, 1, -1, 2, 0, -1, -1, -1, 0, 0], [-3, -1, -2, -1, -1, 0, 1, 1, 0, -1, -1, -1], [-3, -1, -2, -2, 1, 1, 1, 2, 2, 0, -1, -1], [2, -1, 1, 0, 0, 0, -1, -1, 0, 2, 0, -1], [0, -1, -2, 0, -1, 2, 1, -2, -1, -2, 1, -1], [1, 0, 1, 1, 0, -2, 1, -1, 1, 0, 0, 0], [2, -2, -2, 2, 0, 0, -2, 0, 0, 0, 0, 0], [-4, -1, 0, 1, 0, -1, 1, 3, 0, 0, 1, 2], [1, -2, 0, 0, 2, 0, 1, 0, 0, -2, 0, 0], [-3, -2, -2, -3, 1, -2, 0, 4, 2, 0, 1, 1], [-4, -1, -1, -3, 2, -1, 2, 1, 1, 0, 1, 0], [0, 1, 0, 2, 1, -1, -1, 2, 1, -1, 1, 0], [1, -1, 3, -3, 0, 2, 1, 1, 2, 2, 0, 1], [-2, -1, 0, -2, 0, 3, -1, 3, 1, -2, -3, 0], [0, 1, 2, 3, 1, 0, -1, -5, -2, 0, -1, -1], [0, -2, -1, 0, -3, -1, -2, 0, -1, 1, 0, 1], [-2, 1, -1, 0, 0, -6, 1, 1, 2, 2, 0, -1], [2, -1, 0, -2, -2, 3, -1, -1, 1, 0, -2, -2], [-9, 1, 1, -1, -2, 1, 1, -2, 1, -1, 0, -1], [0, -3, 1, 1, -2, 1, -2, 1, -1, 2, 1, 0], [-2, -2, -5, -1, 0, 4, 2, 1, -1, -2, 0, -2], [0, 1, 3, 0, 1, -2, -1, -4, 1, 3, 1, 2], [3, 0, -5, -2, 0, 0, 2, 1, 1, 0, -2, 0], [-1, 2, -1, -4, 0, 4, 4, 2, 1, 3, 2, 1], [-6, 2, -5, -2, 1, -1, 2, 1, 2, 0, 2, 3], [-2, -1, 4, 1, 2, -1, 2, 2, 0, 0, 2, -1], [0, 1, -1, 3, -1, 0, -3, -3, 0, 0, -1, 1], [-1, -2, 2, 2, -2, 1, -3, 5, 1, 0, -4, -1], [-2, 0, 6, 1, 1, -2, -1, 1, 0, 0, -1, -1], [0, 1, 4, 2, 2, 3, 1, 1, 1, -3, 0, 1], [-6, 0, -1, -2, -1, 5, 6, -2, 2, 0, 2, 1], [-2, 1, 4, 2, 1, 3, 3, -1, -3, 1, 2, 2], [2, 1, 3, 1, 1, 4, 0, 0, -2, 0, 2, 0], [-10, -4, -4, -2, 0, 1, 1, 1, 1, 0, 0, 0], [-5, 0, -3, -1, -2, 5, 0, 5, -1, 0, 1, -1], [-4, 5, -2, -1, 0, 2, 1, -6, 2, 0, -2, -2], [-2, 2, 5, 3, -1, -5, -2, -5, -3, 3, 4, 2], [0, 0, 3, 3, -1, -6, -1, 1, 1, 4, -1, 0], [0, -2, -2, 0, 2, -3, 3, 1, 5, 1, 0, -1], [4, 4, 0, 5, 0, -2, 1, -8, -5, 0, 3, 1], [-1, -4, -1, 3, 0, 0, 1, -6, -2, -2, 3, -1], [-2, 1, 1, 4, 3, -4, -3, -4, 0, -1, -1, 1], [-4, -1, 3, 2, -3, -1, -1, -1, -3, -1, 2, 0], [-2, -2, -4, 1, 2, 2, -1, -7, -2, -3, 1, -1], [6, 5, 5, 0, -1, -4, 2, 1, 0, 0, 1, 1], [-4, 3, -4, -4, 0, 4, 0, 0, 1, 2, 2, 1], [-10, 0, -7, -5, -1, 4, 6, -4, 1, -1, -1, -2], [-4, 1, 0, -1, -2, 1, 2, -2, 0, -4, -2, -1], [-4, 1, 1, 2, 3, 4, 0, -1, -2, 1, 2, -2], [-2, 5, 8, -2, 2, 3, -1, 1, 0, -1, 1, 0], [3, -5, 1, -4, 1, 4, 4, 5, 0, 1, 0, -1], [5, 3, 3, 2, 1, -2, 1, 1, -2, 2, 5, 3], [11, -1, 4, 1, 1, -8, -5, 4, 1, -2, -3, -1], [6, -1, 3, 4, 1, -3, 1, -6, -3, -1, 3, 0], [-8, -1, 7, -2, 1, 0, -2, -1, 0, 3, -2, 2], [-1, -2, -2, 5, 3, -6, -5, 5, 0, -2, -1, 0], [-4, 0, -10, -4, -4, 8, 0, -3, 0, -2, -4, -2], [-11, 1, 4, -1, -3, -2, -1, -3, 0, -1, -1, -1], [2, -3, -9, -1, 0, 3, -2, -3, -1, -1, -3, -3], [-10, -1, -2, -2, 0, 1, 3, 1, 6, -5, -3, -4], [6, 3, -3, 5, -4, 4, -4, -7, -4, 0, -2, -1], [-6, 5, 5, -1, 1, -10, 0, -3, 0, 6, 2, 2], [-2, -2, -2, 1, 1, 8, -3, 1, -2, 2, 1, 1], [0, 8, 6, 1, 1, 6, 4, 0, -2, 0, 1, 2], [4, 0, -2, 5, 3, -10, -2, 5, 1, -1, 0, 2], [1, 2, 1, 4, 2, 0, -6, -3, -1, 0, -2, 2], [4, 1, 3, 8, 3, -2, 1, 1, -3, -2, 3, 1], [-9, 4, 8, -2, 0, 1, 3, -1, 3, 1, 2, 0], [-4, -5, -1, -2, 3, 4, 1, 7, 1, -1, -4, -2], [-6, 5, 4, 1, -4, -1, 0, -7, -6, 0, 0, -5], [-1, 5, 7, -2, -3, 3, -1, 5, 0, -2, -2, 3], [2, 2, 2, 4, 0, 2, -4, 1, -1, -1, 2, 0], [0, -3, -8, -3, -2, 2, 3, 4, 4, 0, -2, -2], [1, 5, -2, -5, 2, -4, -2, 4, 3, -2, -4, -3], [-1, -1, -3, 0, -1, 2, -7, 9, -2, 2, -2, 1], [-5, 4, 3, -4, -5, 6, 1, -3, -1, -2, -1, 0], [-3, 6, 9, 1, 5, 3, 0, -1, 0, -2, 2, 3], [5, 1, -7, 1, 2, 2, -1, -3, 4, 0, 0, 1], [6, 1, 5, 3, 1, -4, -6, -2, 0, 4, 0, -2], [-2, 0, -7, 1, -2, 10, -4, 1, -1, 0, -6, -4], [5, 2, -5, -2, 1, 0, 1, 9, -1, 2, 3, 2], [-1, 3, 3, -1, -2, 2, 1, 3, -3, 5, -1, 1], [1, 0, -8, -2, -4, -4, 0, -4, -2, 2, 2, 1], [4, 3, 10, 2, -2, 5, -1, -5, -2, -1, 1, 4], [-2, 6, -6, -3, -3, 4, 6, -13, -1, -1, 2, 0], [2, -3, 5, 2, 5, -11, -1, -2, -3, 0, 4, 1], [-8, 3, -1, -4, 1, 4, 1, 9, -2, -1, -1, 1], [5, -2, 3, 1, -1, -4, -2, 3, 4, 8, 0, -1], [5, 6, 9, 6, 6, -4, -2, 1, 1, 2, 2, 2], [-10, -2, -4, -6, 0, -1, 4, 2, 4, 4, 2, 0], [7, 4, 3, 1, 2, -4, -3, -2, 2, 1, 1, 4], [5, -1, -1, -3, 4, -6, 1, 5, 0, -4, 0, 1], [2, -2, -6, 1, 1, -4, -2, -8, 0, 0, -3, 2], [2, 4, 7, 3, -7, -1, -3, -5, -4, -3, -3, -2], [7, 4, 6, 4, 0, -2, -2, -8, -3, -5, 4, -3], [8, 2, 5, 3, -7, 8, 1, -15, -3, -2, 1, -2], [-2, -3, -5, -2, -3, 0, 0, 11, -2, -4, -1, -3], [3, 4, -4, -1, -2, -6, 0, 10, 0, 2, -2, -2], [-2, 5, 3, 3, -5, 2, -4, 4, 2, 6, 0, 4], [-8, -9, -6, -3, 4, -9, 1, 7, 8, 2, 1, 0], [-9, -4, -1, 4, -1, -8, -4, -3, 0, -2, 4, 2], [-9, -7, -6, -6, 5, -8, 0, 8, 5, 2, 1, 3], [-3, 3, 3, -3, 0, 3, 4, 3, 5, 7, 1, 6], [-4, -1, 8, -3, 0, 5, 5, 2, 2, -4, -2, -2], [4, 6, 0, -2, -4, 10, 6, -1, 2, 4, 0, 0], [8, -3, 7, 3, -4, 10, -1, 1, -6, -4, -1, -4], [6, -3, -8, -1, -1, 12, -1, 9, 2, -5, -9, 0], [10, 6, 10, 7, -1, -2, 0, -6, -8, 0, 7, 6], [5, 5, 12, 3, -1, 1, 4, -2, -3, 3, 5, -1], [-10, 5, -2, -1, -2, -3, 4, 0, 4, 0, -2, -1], [-4, -6, -15, -6, 1, -1, -2, 3, 4, 2, -2, 3], [-5, -3, -3, 2, -5, -4, 0, 3, -2, 0, -4, -2], [-1, 7, 11, -3, 2, -4, 5, -6, 2, 1, 5, 2], [-1, -4, -5, -6, -1, -5, 3, 10, 5, 2, 2, -4], [16, -4, -2, 2, 0, 0, -4, -3, 0, -2, 3, 0], [-6, -1, -5, -6, 1, -4, 1, 0, 7, -2, -1, -3], [-9, 1, -3, -5, -2, 0, -3, 4, -5, 1, -2, -3], [-4, 2, -1, -6, 0, -5, 4, -3, 0, -2, -1, 4], [5, -1, 2, 1, 5, 6, 7, 6, 3, -6, 5, 3], [-1, 0, 1, 5, -3, 6, -4, 7, -3, 6, 1, 4], [0, -2, -7, 1, 3, 3, 3, -9, 0, -1, 1, 0], [3, -4, -9, -2, 3, 6, 0, 1, 0, -4, -6, -6], [-9, 2, 8, -4, 6, 1, 2, -2, -1, -3, 2, 1], [12, -2, 4, 5, 3, -8, 0, 6, -4, 2, 7, 8], [-2, 3, 5, 3, -5, -4, 0, -7, -5, -1, -2, 4], [2, 0, -7, -2, 5, -15, 0, 13, 5, 5, 2, 5], [8, 0, 2, -1, 5, -6, 8, 0, 2, 0, -1, -4], [-6, 1, 3, -4, 1, 9, 1, 12, -3, -2, 2, 3], [0, -5, -3, -3, -4, 6, 4, -9, -4, 0, 0, -1], [8, 4, 10, 7, -1, -14, -10, -6, 1, 1, -3, 0], [4, 1, 4, 2, -5, 2, -5, -8, -11, 1, 1, -2], [-2, -1, -3, 0, 1, -15, -7, -1, 1, 3, 0, -2], [0, 1, -4, -8, 2, -3, 1, 15, 5, 8, 0, 4], [9, -7, -8, 2, 2, -6, 4, -8, -6, -7, 2, -2], [-16, -1, 4, 1, 2, 5, -2, -1, 4, -4, -2, 1], [13, -2, -11, 9, 1, -1, -8, 6, 0, -2, -3, 5], [-14, 1, -6, -5, -3, 9, 6, 0, 1, -2, 1, 1], [5, 1, -17, -5, 0, -7, -2, 3, 1, 3, 1, 6], [4, 1, -7, -1, 3, -12, 0, -8, 6, 6, -4, -2], [-13, 0, 3, -2, 2, -2, 0, 13, 1, -2, 0, -2], [-7, -1, -13, -3, -2, 22, 5, 0, 0, -7, 1, -2], [13, -8, -4, 6, 2, -1, 2, -3, 1, -1, -1, -5], [-5, 5, 13, 3, -1, 2, -2, 7, 0, 2, 1, 1], [-6, 7, -2, -2, -6, -3, 3, -3, 1, 2, -2, -4], [10, 2, 8, 7, 1, -9, -4, -14, 1, 4, -1, -1], [9, 1, -4, 8, -5, -5, -7, -13, 2, -4, -4, 1], [0, 10, 14, 1, 0, -8, -3, -12, -2, 7, 3, 3], [-7, 3, 3, 2, 1, 10, 7, -6, -2, -4, 3, 5], [9, -7, -9, -4, 6, 10, 6, 13, 8, 0, 0, 1], [-2, -2, 2, 7, 1, -6, 8, 4, -5, -5, 7, 2], [5, -2, 8, 0, 2, 4, -4, 8, -4, -4, 2, 1], [11, 8, -1, 2, -2, 14, 2, -5, -3, 2, 0, 0], [-6, 8, 0, -3, 0, -4, 5, -6, -2, 2, 4, 6], [0, 1, -13, 3, -3, -4, 2, 11, 0, -2, 4, 0], [-16, -4, 4, -6, 1, -4, -1, 12, 4, -4, -7, -2], [17, -5, -13, 4, -1, -13, -3, 6, 1, 1, 4, -3], [-8, -6, -9, -6, -4, 1, -8, 7, 6, 4, -7, -4], [4, 9, -4, 7, 1, -3, -4, -14, 1, 0, -3, 3], [-7, -1, -13, -6, 1, 13, 5, -2, -2, -10, -1, -5], [2, 3, -4, 0, 2, -9, 7, -5, 3, -5, -2, 3], [-8, 0, 1, 4, 1, 5, 6, 4, 0, 2, 6, 1], [-6, -9, 4, 8, -4, 5, -3, -6, -5, -6, -9, -2], [7, 6, 3, 5, -5, -8, -6, -2, -6, 2, -1, -5], [-4, 1, 15, -6, 3, -2, 6, -7, 0, 0, 1, -1], [-14, -9, -6, -3, 2, 15, -6, 3, 4, -2, -4, -7], [10, -2, 4, 9, 1, 0, -8, 4, -5, -3, 1, 2], [15, 0, -6, 0, -2, -5, 0, 6, -3, 3, 6, -1], [2, -6, -11, -2, -4, 2, 0, -2, -4, -4, -2, 0], [-11, -1, -15, 1, -8, -14, 3, -9, -2, -2, 2, 1], [-4, -7, -16, 3, -4, -3, -4, 2, -1, 3, 2, 5], [16, 6, 16, 7, 2, -4, -3, -18, -2, -2, -4, -2], [1, -8, -7, -5, -5, 13, 2, 0, -2, -8, 1, -1], [-15, 6, 10, 2, 0, -10, 0, 8, -6, -1, 2, 4], [18, -1, 6, -1, 2, 4, -7, 18, 1, 4, -8, -3], [4, 4, 9, 3, -2, -12, 2, -3, -5, 4, 2, 6], [0, 1, 3, 3, -3, 0, -6, 4, -7, -5, -6, -4], [-11, 5, 9, -5, 2, 8, -1, 12, 0, 3, -1, 0], [-12, -2, 13, 11, 3, -16, -5, -1, 1, 2, 5, 2], [-3, 3, 6, 3, -2, 0, -9, -2, 1, 7, -8, -5], [21, 3, 6, 0, 1, 2, 5, 1, -2, 6, -2, -1], [2, 9, 16, 8, -2, 0, 2, -6, -14, -1, 10, 5], [19, -5, 2, -3, 1, -4, -7, 5, 6, -4, -5, -2], [10, 3, -4, 8, 2, 11, -1, -5, -14, -7, -1, -2], [-12, -4, 7, 7, 3, -3, 7, 7, 3, 0, -3, 0], [2, 2, 14, 2, -6, -6, 2, 4, -2, -1, -2, 1], [4, 2, 2, -5, 3, 2, 3, -7, 8, 5, 3, 0], [-4, -5, 0, -4, 3, 4, 3, -3, 9, 3, -2, 0], [-7, 8, -6, 5, -3, -3, -6, -6, -3, 4, 3, 10], [6, 6, 6, 4, 4, 13, -3, -7, -11, -2, 8, 8], [-10, 3, 1, -6, -3, 2, 0, 1, -4, -2, -5, 1], [4, 2, 10, 5, 7, -10, -4, -8, -7, 1, 3, 8], [-12, 1, -2, -10, 1, 3, 1, 18, 9, -3, -9, -4], [1, 1, 8, -6, -3, 10, 4, 6, 3, -4, -9, -5], [-18, 2, -1, -2, 3, -19, 0, 4, 9, 3, 6, 1], [-10, 2, 6, -3, 8, 4, 3, 12, 4, 5, -1, -5], [10, -3, 0, -2, -5, 8, 3, 2, -5, 4, 1, -3], [8, 5, -5, 0, 5, 12, 5, 10, -2, -5, 1, -3], [8, 1, -1, 6, 7, 0, -2, -11, 8, 4, 1, 1], [8, 8, -2, 2, -6, 17, -4, -22, -8, -2, 0, 2], [4, -3, 8, -10, -2, 15, -1, 0, 4, 1, -7, -4], [-23, -4, -9, -1, -2, 10, 1, 18, 6, 0, -1, 1], [-20, -10, -8, -10, 0, -4, 6, 11, 7, -5, -2, -4], [3, 5, 12, 5, -9, 3, -10, -18, -5, 0, -3, 2], [1, 2, -9, -6, 5, -6, -3, 5, 7, 0, 1, -6], [8, -1, 4, 3, 4, -18, -1, -4, 6, 6, -6, -2], [-9, -5, -10, 3, 2, -4, 1, 8, 5, 3, 4, -5], [5, -9, -2, -5, -3, -4, 1, 6, -3, -6, -5, -5], [-6, 1, 0, 3, 6, 3, 0, -2, -6, 2, 8, -3], [9, -2, -11, 2, -1, -7, 7, 8, 3, -4, 0, -2], [4, 2, -5, 1, 1, -16, 7, 1, 3, 2, 7, 6], [-20, 6, -5, -5, 3, -9, 5, 5, 2, -1, -3, 6], [0, -3, 6, 7, -4, -5, -9, -6, -6, 0, 0, -2], [-18, -8, -16, -13, 0, 10, 1, 11, 6, -9, -13, -3], [-1, 9, 5, 7, -6, 15, 0, -9, -5, -2, 7, 7], [20, 7, 3, 10, -2, -2, 1, -23, -10, 4, 4, 9], [-20, -4, 5, -5, 3, -5, 11, 7, 5, -4, 5, 8], [1, -5, -10, -4, 0, 1, 7, 5, 11, 4, -4, -5], [5, -9, 0, -4, 9, 5, 7, 5, 8, 4, -2, -1], [16, 5, 4, -2, -1, 16, -5, 4, -3, -4, 1, 3], [12, 5, 1, -1, 10, -1, -1, 6, -4, -2, -2, -2], [9, 3, 12, 8, -1, -4, -2, 2, -3, 4, 3, 13], [6, -3, -12, -5, 0, 8, 5, 10, 4, -6, 2, -8], [4, -1, -12, -2, 0, -13, 3, -8, -2, -5, 5, 2], [-14, -7, -13, 0, -3, 8, -5, -5, -3, 0, -7, -3], [-5, 6, -6, -4, 0, 6, 1, -8, 2, 6, 0, 0], [-4, 3, 11, -2, 0, 14, 9, 3, -2, 0, 2, -1], [-1, -5, -4, -1, -4, -8, -3, -8, 1, -5, -2, -3], [5, -1, -9, -13, 4, -4, -3, 10, 6, 7, -5, -6], [8, -6, -3, 3, 1, 13, -2, -7, -7, -9, 8, 2], [4, 9, 16, 17, -6, -15, -14, -16, -12, 0, 2, 1], [11, 8, 19, 5, -6, 8, -3, -28, -10, -1, 1, -2], [10, 10, 8, -3, 2, -14, 7, 0, 0, 5, 11, 9], [-21, 4, 1, -6, 0, 22, 8, 3, 1, -6, -4, 4], [-8, 6, -4, -1, 2, 10, 11, -3, 5, 8, 3, 9], [-3, -4, -13, -6, 1, 12, 12, 11, 0, -5, 6, 3], [-1, -9, -6, -5, -2, -4, 1, 5, 3, 1, 3, 1], [-5, -4, -7, 4, 3, -4, 8, -11, -4, 2, 4, 2], [13, 2, 1, 0, -2, -9, 4, 0, 1, 3, 12, 7], [-16, 11, -18, -4, -2, -1, 5, 7, 6, 3, 5, 4], [-5, 10, 12, 2, -2, -4, -7, -18, -2, 0, -2, -4], [3, 1, 5, 0, 6, -2, -6, -7, -2, -2, 2, 5], [4, -12, -14, -2, -2, 1, -2, 6, -2, 0, 2, -8], [-19, 7, -7, -5, 2, 6, 5, -1, -4, -8, 6, 11], [-11, 2, 6, -13, 1, 2, 6, 1, 8, 10, 0, -1], [16, -10, 12, 3, -1, 2, -6, 6, -6, -2, 9, 4], [0, -6, 8, 0, 2, -6, 0, 16, 6, 0, -6, -2], [-9, 0, 6, -2, -2, 2, -2, -3, 5, -3, -9, 5], [-13, -3, 4, -6, -8, 9, 7, -1, 3, -9, -4, -4], [20, -2, 3, 14, 1, 2, -12, -15, -8, -2, -4, -5], [5, 6, 8, -6, 4, 0, -7, 10, 2, -4, -8, 2], [-24, -11, -15, -10, 1, 8, 10, 23, 2, -4, 2, 3], [5, 6, 10, -4, 0, 22, 5, -2, -6, -8, -4, -2], [-5, 0, -3, 6, 4, -9, 4, 7, 1, -7, 3, 1], [5, 5, 5, 0, 1, -8, -16, 7, -2, 0, -10, 0], [15, 14, 7, 3, 0, 1, -12, -5, 3, 2, -13, -5], [-10, 8, 16, 2, 0, 14, 4, 7, 4, 2, 2, 2], [2, 7, 15, 0, -3, 8, -5, -30, -10, 1, 5, -1], [-12, -3, 0, -6, -6, -3, 7, -7, -8, 5, 9, 4], [-8, -3, -13, -7, 6, -11, -2, -7, 7, -3, -5, 1], [3, 4, 4, 7, -8, 4, -10, -12, -4, 4, -2, 2], [-5, 6, 10, 13, 5, -1, -2, -11, 2, 2, 6, 11], [13, -1, 6, 7, -5, -8, 1, -2, -5, -4, -1, 5], [-10, -4, -11, -16, 1, 4, 10, 11, 5, 4, 7, -4], [4, 6, 2, -9, 2, 4, 3, 7, 0, 5, -1, 7], [-4, -1, -6, 5, 3, -4, 2, 10, -7, -12, 3, 3], [1, 6, -2, 4, -2, 0, -5, -10, -2, -6, -6, 2], [12, 14, -9, -1, 2, -12, 2, 1, -5, -2, 2, 0], [-2, -2, 5, 12, -5, -3, -8, -17, -11, 1, 4, 7], [-6, 5, 1, -8, 1, 6, 5, 19, 13, 0, -7, 1], [-4, 10, 3, 1, 7, 5, 9, -2, 4, -5, -5, -2], [-15, -7, -18, -5, -1, -4, 3, 16, 9, 8, 1, -5], [-8, 3, -3, -2, 1, -17, 1, 8, 3, 11, 1, 2], [-9, 3, -22, -11, 1, -11, -4, 2, 3, 2, 1, -4], [-2, -7, -9, 5, -7, 2, -2, -5, 4, -4, -8, -2], [-4, -7, 4, -1, 3, -3, 2, 14, -3, -11, -1, -6], [-16, -1, -6, 8, -8, 11, 1, -4, -8, -13, 1, -4], [-19, 6, -2, -3, -3, 11, -6, 2, -1, 0, -9, -4], [18, -1, -4, 9, -1, -2, -11, -7, -12, -8, -1, -3], [-8, 3, 3, 4, 5, -18, -11, -3, -8, -3, -5, 3], [-6, 2, 19, 15, 1, -7, 3, -12, -5, 0, 13, 4], [0, -10, -4, -2, -2, 4, -6, 2, 0, 8, 0, 4], [28, 4, 5, 8, 7, -10, -6, 11, -8, -5, 2, -4], [9, 6, 2, -4, -6, -4, 5, 2, 6, 4, -6, 6], [-9, 8, -4, 0, 0, 3, -4, 4, -7, -9, -6, 5], [-19, 3, 3, -7, -2, -6, 1, -2, 2, -3, -5, -4], [-9, -14, 2, 6, -12, 7, -4, 1, -5, 5, 5, 5], [18, 10, 6, 1, 2, 16, 1, -15, 0, 3, -9, 1], [19, -19, -1, 5, -6, 2, -9, -3, -8, -4, -2, -5], [12, -8, 2, -4, 0, 4, 6, -11, 6, 2, -9, -2], [-8, -7, -13, -10, -3, 22, 10, 9, 0, -2, -1, 3], [28, 1, 4, 4, 3, -10, -5, 6, -3, 4, 3, 1], [-5, 1, 4, 5, 2, -2, -8, -10, -11, 0, 10, -1], [-12, 7, 11, 6, -1, -12, -1, -10, -7, 9, 7, -4], [2, 13, -3, -4, -5, -11, -7, -12, 3, 10, -6, -1], [3, 11, 7, 3, -2, -6, 3, 11, -3, 7, 1, 5], [-10, -6, -3, 2, 3, -19, -7, -4, 5, 0, 8, -1], [7, 5, 23, 5, -3, 8, -2, -11, -8, -6, -5, -11], [0, -5, -12, 5, -6, -2, -1, -7, 2, 8, -9, -10], [-18, -1, -18, 0, 4, -3, 3, 11, -2, -3, -3, 0], [-12, -11, 0, -5, -1, 14, 0, -4, 7, -4, -9, -1], [-10, 10, 1, -3, -2, -1, 2, 13, 5, 8, -11, 0], [16, -7, -8, -9, -2, 14, -3, 7, 8, 4, -7, 0], [0, -13, -12, 4, -1, 3, -11, -3, -5, -9, -8, -10], [-10, 2, 4, -5, 9, -2, 12, 12, 14, -2, 1, 0], [-7, 5, -8, 5, -3, 14, 9, -4, -1, -6, 1, 3], [-16, 1, -5, -17, 3, 14, 8, 6, -2, -6, 2, 2], [-20, 5, 1, 0, -9, -10, -1, -11, -4, 3, -1, 3], [-14, 3, 0, 8, 5, -6, -9, 6, 3, 11, -1, 8], [-5, -2, 23, 10, 1, -14, 0, 11, -2, 3, 0, -1], [-14, -4, -1, 1, -1, -5, 1, 5, 4, 5, -1, 10], [-9, -2, -11, -1, -5, 7, 6, -26, -6, -4, -1, -3], [-31, -3, -14, -6, -4, 11, 7, -5, 3, 4, 0, 1], [-4, -9, -6, -10, -8, -1, 9, 1, -2, 5, 1, -8], [-10, 5, 6, -2, 0, -18, -4, -14, -3, -4, -4, 1], [-4, 6, -9, -1, 10, 1, 2, 25, 11, -3, 3, 5], [12, 6, 6, 2, -2, 0, -12, -14, 0, 2, -6, -10], [1, -6, 0, 0, 0, 7, -6, -4, -11, -11, -8, -9], [13, 7, 7, 0, 7, -1, 3, 14, 3, 7, 6, 7], [-12, -6, 8, -8, 2, 13, 1, -1, 7, -3, 2, -1], [14, -6, 18, 0, -4, 11, 3, 13, -9, 8, 0, 2], [-13, 7, 9, 6, -1, 12, 5, 0, -6, 2, -5, -7], [-22, -1, -14, -8, 6, 16, 2, 0, 10, -1, -8, -7], [-15, -13, 3, 6, 1, -8, 5, -13, -4, -6, 6, -3], [-4, -8, -15, -5, -5, 4, -7, 3, -1, 0, -7, -8], [-21, 6, 4, -3, -1, -3, -2, -4, 6, -2, -11, -1], [24, 11, 10, 9, 1, 9, 2, -6, -7, 3, 5, 8], [8, -9, -3, -8, 3, 6, -3, 2, 4, 7, -7, -7], [10, 10, -4, 7, -1, -19, -6, -2, -1, 7, -9, 6], [-6, -9, 6, -8, 5, -4, -3, 17, 15, 5, -8, 6], [21, -6, -2, -8, -5, -2, -2, -2, 2, 6, 3, -2], [2, -4, -1, 2, 0, -4, -9, 5, -3, 4, -8, 0], [-7, -6, -11, -13, -5, -4, 4, 11, 9, -4, 1, 0], [-9, -1, 8, 6, -5, 7, -3, -8, -2, -16, -7, 3], [-8, 9, 8, 1, -6, -19, 2, -17, -6, 2, 12, 5], [1, 4, 4, -2, 0, 14, 5, 0, -4, -10, 2, -6], [26, -7, -8, -9, 4, 8, -1, 22, 14, 6, -6, -4], [-19, -1, -3, -2, -1, 24, 3, -22, -6, -4, 5, 7], [23, 2, 4, 2, 3, -18, -4, -12, -6, 4, 1, 2], [7, 5, 17, 1, -4, -20, -11, -19, -5, 7, -5, 5], [21, 14, 3, 0, -5, 1, 3, -8, 1, 3, 6, -1], [24, -4, -12, -1, 4, -18, -5, 10, -4, 7, 1, 13], [-21, 5, 8, 9, -3, -25, -4, 10, 3, 9, 9, -3], [-2, 4, 12, 12, -8, -4, -14, 0, -6, 10, -2, -2], [1, -4, -4, 0, -6, -7, -11, -7, -1, 10, 0, -1], [0, -11, -12, -10, 6, 3, 3, 3, -1, 2, 7, -2], [16, -10, -16, -3, 5, 4, 2, 12, 4, 0, 3, -4], [-4, -6, 15, 4, 5, -17, 4, 3, -2, -2, 10, 9], [0, -2, 12, 15, -1, 1, 2, -11, 1, 5, 4, 0], [5, 4, -6, -1, 1, 16, 13, -11, -4, 0, 1, 10], [9, 4, -5, -6, 1, -4, 1, 15, 3, 14, 5, -2], [-2, 4, 7, 2, 7, -10, -6, -11, -4, -4, 8, 3], [-18, -7, 13, 7, 2, 3, 9, -5, 4, 2, 11, 0], [-6, -7, -4, 2, 0, -2, -4, -8, 1, 2, -2, -13], [-7, -3, 6, 1, 12, -9, -1, 11, -3, 3, 3, 7], [5, -8, 8, 6, 4, 6, -7, -2, -4, -12, -4, -12], [9, -12, -2, 15, -3, -4, -17, -6, -14, -6, 3, -4], [5, -8, 12, 1, 1, -4, -5, -25, -4, 0, 11, -6], [-15, 6, -9, -4, 5, 10, 5, 5, 5, 2, 5, 6], [-25, -15, -29, -7, 0, 1, -1, 20, 3, -3, -2, 1], [-8, -11, 1, 8, -7, 6, -13, -5, -8, 9, 1, -1], [-5, -7, 4, 10, 3, 3, -17, -29, -8, -2, 0, -1], [-26, 2, -1, -1, 6, -3, 6, 9, 9, 4, 1, -2], [4, -10, -13, -5, 3, 1, 7, 0, 13, -2, -1, -16], [22, 1, 3, -5, 1, -18, 4, 6, 6, 0, -2, -8], [-5, -2, -9, 7, 2, -7, -6, -7, 5, 8, -3, -5], [-7, -2, -4, 3, 5, -6, 8, -4, 4, -4, 1, -7], [1, 19, 9, 4, 5, 2, -3, 1, 8, 2, -6, 3], [-9, -10, -7, -10, 6, 8, 4, 5, 5, -6, -4, -6], [-14, -8, -34, -15, -2, 6, 7, 2, 10, -7, 1, 5], [11, -15, -15, 6, 3, 6, -5, -1, 0, 2, -7, -7], [17, 6, -3, -11, 5, -4, 8, -1, 6, 10, 2, -1], [-6, -12, 19, 6, -7, 22, 4, -3, -11, -14, -3, -8], [-9, 13, 2, -2, 0, -7, -7, -19, 1, 5, -4, -6], [-4, 13, 6, 1, -1, -1, 6, -20, -13, -6, 11, 1], [-5, -2, 6, -3, 9, -35, 0, 6, 2, 8, 15, 5], [-9, 1, 26, -7, 3, 1, -4, 2, 7, 10, 3, 2], [-2, -8, 18, 5, 2, 10, 5, 7, 0, -5, 3, 9], [-14, -18, -26, -17, -3, 10, 2, 12, 14, 0, -15, 2], [-1, -1, 19, 4, 1, 7, -11, -8, -9, -3, -2, -5], [-20, -2, 3, 7, 1, -6, -13, -1, -3, -6, 9, 6], [-11, 4, 10, -1, 7, 8, 2, 17, -2, -2, 0, -1], [1, 2, 20, 1, -1, -11, 0, 14, 5, 0, -11, -6], [-14, -8, -2, 0, 0, -8, -6, 2, 6, 0, 2, 10], [15, -7, -2, 3, -6, 6, -4, 0, 5, -2, -8, -1], [-6, -21, -12, -15, 4, 13, 12, 23, 8, -2, 4, -5], [-23, -2, -4, -7, -7, -7, -2, -6, -1, 8, 5, 4], [26, -4, 12, 4, 0, -18, 4, 2, -8, 0, 6, 2], [14, -17, 18, 12, 10, -11, -9, 3, 0, -3, 5, 2], [20, 8, -2, -4, -2, 3, -10, 3, -4, 4, -3, 6], [-22, -15, -2, -7, 0, 7, 4, 9, 21, 1, -2, 1], [-13, 6, 13, 13, -3, -11, -16, -19, 0, 8, -6, -1], [-9, 4, 6, -4, 4, -16, 1, -18, 4, 2, 2, 8], [-6, -17, -26, -10, -1, 0, -3, 20, 17, 4, -7, -5], [-14, 8, 1, -3, 2, -3, 4, -1, -5, 5, 1, -9], [-14, -6, -8, -3, 4, -4, 13, 8, 0, -5, -9, -9], [-21, -11, -11, -8, 3, 1, 1, -3, 8, 2, 0, -7], [4, 0, 9, 7, 5, -8, -9, 5, -9, 4, 5, -2], [6, -7, -15, -11, -1, 14, -6, 2, 3, 9, -12, -12], [-17, 1, 5, 5, -1, 14, 2, 5, -4, 6, -3, 5], [-26, 1, 7, 0, 7, 9, 9, -4, -5, -9, -3, -12], [3, -6, -13, 2, 3, -12, -4, 1, -2, 1, -10, -1], [12, 15, 12, -2, -5, -4, 9, -10, 5, 10, 7, -5], [-22, 1, 15, -4, 4, -2, 7, 3, -4, -4, 10, 3], [3, 6, 4, 0, 0, -14, -6, -8, -3, -3, -6, -5], [3, -3, 11, 6, -6, -28, -8, 5, 2, 12, -4, -1], [7, 1, 5, -3, 4, -22, -1, 2, 11, 9, 6, -1], [-20, -14, -10, -5, -7, -3, -8, 19, -3, -9, -12, -10], [8, 15, 6, 16, 0, 8, -10, -6, -4, 0, -4, 10], [4, 13, 0, -11, -11, 12, 3, -7, 0, 14, -3, 5], [-14, -3, -3, 6, -7, 0, 0, 17, -8, -6, -3, 5], [-2, -12, -7, -11, 5, -21, -7, 11, 12, -1, -1, -4], [-9, 6, 4, -9, -1, -14, 3, 5, 6, 4, 1, 6], [-5, -11, -17, -5, 6, -3, -10, 17, 11, 16, -5, -5], [-26, -4, 7, -4, 3, 25, -4, 11, 0, -4, -6, 1], [-15, 5, -2, 6, -2, 8, 0, -24, -2, 2, -12, -7], [-2, 3, -11, 1, -7, -4, -5, 15, -2, 6, -9, 1], [7, 1, -29, -5, -8, 31, -10, 11, 3, 2, -11, -5], [2, 9, -2, 1, 8, 3, 1, -1, -12, -6, 5, -2], [10, -6, 4, 8, -6, 8, -14, -5, -18, -8, 0, -4], [-12, 7, 5, 1, 0, 28, -1, 0, 2, -4, -10, 4]]
